@@ -270,6 +270,15 @@ Schemars can implement `JsonSchema` on types from several popular crates, enable
 - [`url`](https://crates.io/crates/url) (^2.0)
 - [`bytes`](https://crates.io/crates/bytes) (^1.0)
 - [`enumset`](https://crates.io/crates/enumset) (^1.0)
+- [`rust_decimal`](https://crates.io/crates/rust_decimal) (^1.0)
+- [`bigdecimal`](https://crates.io/crates/bigdecimal) (^0.3)
+
+For example, to implement `JsonSchema` on types from `chrono`, enable it as a feature in the `schemars` dependency in your `Cargo.toml` like so:
+
+```toml
+[dependencies]
+schemars = { version = "0.8", features = ["chrono"] }
+```
 */
 
 /// The map type used by schemars types.
